from distutils.core import setup

setup(
    name='listprinter',
    version='1.3.0',
    py_modules=['listPrinter'],
    author='ajagor')
